@@ -27,8 +27,6 @@
 
 #include <gtk/gtk.h>
 
-#include <dbus/dbus-glib.h>
-
 #include "bluetooth-client.h"
 #include "bluetooth-client-private.h"
 #include "gnome-bluetooth-enum-types.h"
@@ -47,7 +45,7 @@ static void delete_callback(GtkWidget *window, GdkEvent *event,
 
 static void scan_callback(GtkWidget *button, gpointer user_data)
 {
-	bluetooth_client_start_discovery(client);
+	g_object_set (G_OBJECT (client), "default-adapter-discovering", TRUE, NULL);
 }
 
 static void select_callback(GtkTreeSelection *selection, gpointer user_data)
@@ -60,7 +58,7 @@ static void select_callback(GtkTreeSelection *selection, gpointer user_data)
 		return;
 	}
 
-	bluetooth_client_dump_device (model, &iter, FALSE);
+	bluetooth_client_dump_device (model, &iter);
 }
 
 static void row_inserted(GtkTreeModel *model, GtkTreePath *path,
@@ -74,7 +72,7 @@ static void row_inserted(GtkTreeModel *model, GtkTreePath *path,
 static void proxy_to_text(GtkTreeViewColumn *column, GtkCellRenderer *cell,
 		GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-	DBusGProxy *proxy;
+	GDBusProxy *proxy;
 	gchar *path;
 
 	gtk_tree_model_get(model, iter, BLUETOOTH_COLUMN_PROXY, &proxy, -1);
@@ -84,7 +82,7 @@ static void proxy_to_text(GtkTreeViewColumn *column, GtkCellRenderer *cell,
 		return;
 	}
 
-	path = g_path_get_basename(dbus_g_proxy_get_path(proxy));
+	path = g_path_get_basename(g_dbus_proxy_get_object_path(proxy));
 
 	g_object_set(cell, "text", path, NULL);
 
